Learn R Programming

lehuynh (version 0.1.1)

new_project: Create a new project

Description

This function sets up a new project within an active R project for reproducible purposes.

Usage

new_project()

Arguments

Value

A project containing folders and files for reproducible purposes.

Details

The project includes:

  • README.md: the top level description of content in the project

  • Makefile

  • different folders to hold all data, code, results of data analysis, and documents related to the project

  • templates: manuscript.Rmd, code.R, etc.

References

Reproducibile Research Tutorial Series by Pat Schloss.

Examples

Run this code
# \donttest{

if(interactive()){
  new_project()
}
# }

Run the code above in your browser using DataLab