powered by
This function sets up a new project within an active R project for reproducible purposes.
new_project()
A project containing folders and files for reproducible purposes.
The project includes:
README.md: the top level description of content in the project
Makefile
different folders to hold all data, code, results of data analysis, and documents related to the project
templates: manuscript.Rmd, code.R, etc.
Reproducibile Research Tutorial Series by Pat Schloss.
# \donttest{ if(interactive()){ new_project() } # }
Run the code above in your browser using DataLab